package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"(```````!``````````#"Q````
M`````````$``.``-`$``&P`:``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````#@;````````.!L`````````
M$`````````$````%`````"``````````(``````````@````````?3L`````
M``!].P`````````0`````````0````0`````8`````````!@`````````&``
M``````#H10```````.A%`````````!`````````!````!@```,"K````````
MP+L```````#`NP```````&`$````````X!0`````````$`````````(````&
M````T*L```````#0NP```````-"[````````(`(````````@`@````````@`
M````````!`````0````X`P```````#@#````````.`,```````!`````````
M`$``````````"``````````$````!````'@#````````>`,```````!X`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````0`````````!```````````@`````````4.5T9`0`
M``"0G@```````)">````````D)X```````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````P*L```````#`NP```````,"[````
M````0`0```````!`!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!0````#````
M1TY5`+XB,4+.&WG$@;(_DBE;KM)9<`^S!````!`````!````1TY5```````$
M````!```````````````/0```$`````$````"````"`<$``%0`2&*`)`!)"&
M`(2""0`@22`$"+BB$$6Z``(*``````````!``````````$$```!#````10``
M``````!&`````````$<```!(````20```$L``````````````$P`````````
M````````````````````````````````30```$X```!0````4@``````````
M`````````%,`````````5`````````!5``````````````!6````5P``````
M``!8````60```````````````````%H`````````6P``````````````7```
M`%T```!?``````````````!@`````````````````````````+OCDGRFW:-K
M:QJ>4"[%F[9#^M>'%8PES&>OS&9OQ=\?B0=PT\2)!9"CX/M)^Z%L8-5DU'S#
MY3\L?JF<FZU+X\#B1\8!S]Y'+0T4XIXA_^0.X:<""MO-XYX+BA!7LP&+;PTZ
MEPO9<5@<5Z2;EC-BV^UK"4/6Q+F<0#GRBQQ#1=7L:W^:?```````````````
M`````````````````!H!```2`````````````````````````(H!```2````
M`````````````````````.0!```2`````````````````````````,(!```2
M``````````````````````````$````@`````````````````````````.L!
M```2`````````````````````````&H"```2````````````````````````
M```"```2`````````````````````````)<````2````````````````````
M`````#X"```2`````````````````````````%0"```2````````````````
M`````````-@````2`````````````````````````#T#```2````````````
M`````````````!4!```2`````````````````````````","```2````````
M`````````````````!4"```2`````````````````````````-,!```2````
M`````````````````````&,"```2`````````````````````````#\"```2
M`````````````````````````',"```2`````````````````````````.<`
M```2`````````````````````````+L````2````````````````````````
M`/4````2`````````````````````````+<!```2````````````````````
M`````,H!```2`````````````````````````-,"```2````````````````
M`````````!\!```2`````````````````````````/D!```2````````````
M`````````````(4!```2`````````````````````````+<"```2````````
M`````````````````+`"```2`````````````````````````%,````2````
M`````````````````````!T````@`````````````````````````#<"```2
M`````````````````````````#(!```2`````````````````````````*,!
M```2`````````````````````````"L!```2````````````````````````
M`(`````2```````````````````````````!```2````````````````````
M`````(P````2`````````````````````````%(!```2````````````````
M`````````&4!```2`````````````````````````&,````2````````````
M`````````````$8"```2`````````````````````````+`````2````````
M`````````````````$$!```2`````````````````````````/$!```2````
M`````````````````````'X!```2`````````````````````````*$"```2
M`````````````````````````'H"```2`````````````````````````&\`
M```2`````````````````````````*D"```2````````````````````````
M``X"```2`````````````````````````,D````2````````````````````
M`````*<````2`````````````````````````+T!```2````````````````
M`````````)L!```2`````````````````````````"D"```2````````````
M`````````````"P````@``````````````````````````<"```2````````
M`````````````````(0"```B`````````````````````````!P"```2````
M`````````````````````),"```2`````````````````````````-8#```0
M`!@`H-```````````````````,L"```A`!@`0,`````````(`````````.@#
M```2``X`X%@```````#[`0```````!H#```2``X`T"L````````%````````
M`'\#```2``X`,%<```````"G`0```````#,$```2``X`T%8```````!5````
M`````&8#```2``X`("X````````=`````````$8#```2``X`<#\````````_
M`0```````,P#```1`!<`&,`````````(`````````,H"```A`!@`0,``````
M```(`````````-L#```2``X`0"X```````"G!````````!,$```2``X`D#,`
M```````0`0```````#P$```2``X`L#P```````"Q`@```````/X#```2``X`
MP"H````````R`````````"L#```2``X`<#,````````?`````````)<#```1
M`!```&`````````$`````````%D#```2``X`\"T````````E`````````'(#
M```2``X`H#0````````!"`````````H#```2``X`4%L````````%````````
M``8$```2``X`X"L````````%`@```````*8#```2``X``"L```````#%````
M`````+P#```2``X`X%H```````!E`````````$8````1`!@`,,`````````!
M`````````"4$```2``X`\#(```````!U`````````(P#```@`!<``,``````
M`````````````/(#```0`!@`(,```````````````````',!```1`!@`(,``
M```````$`````````)`#```2``X`8"(````````O`````````(H#```0`!<`
M`,```````````````````,D"```1`!@`0,`````````(`````````%P"```1
M`!@`8,`````````(`````````%(#```0`!<`(,```````````````````,0"
M```2``X`0"`````````>`@````````!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!03%]D;U]U;F1U;7``4&5R;%]G=E]F971C:'!V`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7VQO8VL`4&5R;%]G971?<W8`4&5R;%]N97=84P!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]R=6X`<&5R;%]P87)S90!097)L7W-V7W-E='!V`%!E
M<FQ?<W9?<V5T<'9N`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?9&5S=')U8W0`<&5R
M;%]A;&QO8P!097)L7V-R;V%K7VYO8V]N=&5X=`!P97)L7V9R964`4&5R;%]S
M869E<WES;6%L;&]C`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%-?9FQA9W,`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`4$Q?=&AR7VME>0!O
M<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<'1H<F5A9%]G
M971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED
M`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?
M8VAK`&UE;6-P>0!L<W1A=#8T`%]?<W1R;F-P>5]C:&L`;W!E;F1I<@!S=&1E
M<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN
M86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L
M:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`&QI
M8G!E<FPN<V\`;&EB<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!?7VQI8F-?8W-U
M7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!?961A=&$`<&%R7V)A<V5N86UE`'!A<E]D:7)N
M86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?
M<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I
M;FET`&UY7W!A<E]P;`!?96YD`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B
M<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/
M3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ-`!'3$E"0U\R
M+C,N,@!'3$E"0U\R+C0`1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U+C,R
M+V-O<F5?<&5R;"]#3U)%``````(``P`"``(````"``(``@````0``@````(`
M```"``(`!0`"``0``@`````````#``(`!@````(``P`"``(```````<````#
M``(`````````````````"````````@`#``(``@````(``@```````@`#``@`
M```"``(``@`(``$``@`!``$``0`!``$``0`!``(``0`!``$``0`!``$``0`!
M``$``0`!``$````!``$``0````$``0`"``(``0`!```````!``$`\`(``!``
M```@````=1II"0```P!2!`````````$`!@```P``$`````````!T&6D)```(
M`%X$```0````E)&6!@``!P!J!```$````'(9:0D```8`=00``!`````4:6D-
M```%`($$```0````LY&6!@``!`"+!```$````'4::0D```(`4@0```````#`
MNP````````@`````````4",```````#(NP````````@``````````",`````
M```(P`````````@`````````",`````````8P`````````@`````````X&(`
M```````0O@````````8````!```````````````8O@````````8````"````
M```````````@O@````````8````#```````````````HO@````````8````$
M```````````````PO@````````8````%```````````````XO@````````8`
M```&``````````````!`O@````````8````'``````````````!(O@``````
M``8````(``````````````!0O@````````8````)``````````````!8O@``
M``````8````*``````````````!@O@````````8````+``````````````!H
MO@````````8````,``````````````!PO@````````8````-````````````
M``!XO@````````8````.``````````````"`O@````````8````/````````
M``````"(O@````````8````0``````````````"0O@````````8````1````
M``````````"8O@````````8````2``````````````"@O@````````8````3
M``````````````"HO@````````8````4``````````````"PO@````````8`
M```5``````````````"XO@````````8````6``````````````#`O@``````
M``8````7``````````````#(O@````````8````8``````````````#0O@``
M``````8````9``````````````#8O@````````8````;``````````````#@
MO@````````8````<``````````````#HO@````````8````=````````````
M``#PO@````````8````>``````````````#XO@````````8````?````````
M````````OP````````8````@```````````````(OP````````8````A````
M```````````0OP````````8````B```````````````8OP````````8````C
M```````````````@OP````````8````D```````````````HOP````````8`
M```E```````````````POP````````8````F```````````````XOP``````
M``8````G``````````````!`OP````````8````H``````````````!(OP``
M``````8````I``````````````!0OP````````8````J``````````````!8
MOP````````8````K``````````````!@OP````````8````L````````````
M``!HOP````````8````M``````````````!POP````````8````N````````
M``````!XOP````````8````O``````````````"`OP````````8````P````
M``````````"(OP````````8````Q``````````````"0OP````````8````R
M``````````````"8OP````````8````S``````````````"@OP````````8`
M```T``````````````"HOP````````8````U``````````````"POP``````
M``8````V``````````````"XOP````````8````W``````````````#`OP``
M``````8````X``````````````#(OP````````8````Y``````````````#0
MOP````````8````Z``````````````#8OP````````8````[````````````
M``#@OP````````8````\``````````````#HOP````````8````]````````
M``````#POP````````8````^``````````````#XOP````````8````_````
M```````````@P`````````4```!:```````````````PP`````````4```!6
M``````````````!`P`````````4```!=``````````````!@P`````````4`
M``!>```````````````(O@````````<````:````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!?F>``!(A<!T`O_02(/$",,``````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@____05152(/L.(E\)!Q(C7PD'$B)="002(UT
M)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP/\5GIX``$B+-<>>``!(BST0
MGP``2(GR9^C/.@``@#V8GP```'4R_Q4@G@``2(D%\:\``$B)QTB%P`^$F@$`
M`/\5KYT``(L]89\``/\56YX``,:`Z0D```"+/4Z?``#_%4B>``"+/4*?``"`
MB#H$```"_Q4UG@``@(@Z!````8M$)!R->`1$C6`#2&/_2,'G`_\5SIT``$B+
M3"00BW0D'$F)P4B)!7.O``!(BP%)B0%(C06D0```28E!"$B+!>.>``!)B4$0
M2(T%D4```$F)01B#_@$/CO8```!(@\$(@\8#N`0````/'X``````2(LY2&/0
M@\`!2(/!"$F)/-$YQG7K2&/V2,'F`T2)XDB+/1*O``!%,<!,B<E)QP0Q````
M`$B--;4(``#_%<>=``!!B<2%P'162(UL)"1(BSWDK@``_Q7VG```,<!(B>Y(
MC3W=/@``Z)4!``!(A<!T0$B+/<&N``#_%9N<``#_%6V=``!(BT0D*&1(*P0E
M*````'5E2(/$.$2)X%U!7,-(BSV3K@``_Q6MG0``08G$ZYA(BSUQK@``2(7_
M=`?H3QT``.NM2(T],#X``$B)[N@N`0``2(D%3ZX``$B)QTB%P'2/Z]F^(```
M`.DO____OP$```#_%6B=``#_%3*<``!FD/,/'OHQ[4F)T5Y(B>)(@^3P4%1,
MC076.```2(T-7S@``$B-/;C]____%6*<``#TD$B-/8F=``!(C06"G0``2#GX
M=!5(BP6&FP``2(7`=`G_X`\?@`````###Q^``````$B-/5F=``!(C352G0``
M2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!>V<``!(A<!T"/_@9@\?1```PP\?
M@`````#S#Q[Z@#U=G0```'4S54B#/=*<````2(GE=`U(BSWFG```_Q7`G```
MZ&/____&!32=```!7<-F+@\?A```````PV9F+@\?A```````#Q]``/,/'OKI
M9____P\?@`````!!5T%6055!5%532(/L"$B%_P^$L0```$R++<*<``!-A>T/
MA*$````/M@=)B?](B?6$P'0$/#UU6$4Q]DV+90!-A>1T,TUC]DR)ZV8/'T0`
M`$R)\DR)_DR)Y_\5:9H``(7`=0=#@#PT/71&3(MC"$B#PPA-A>1UV4B#Q`A,
MB>!;74%<05U!7D%?PP\?@`````!)B?Y!#[9&`4F#Q@&$P'0$/#UU[T4I_NN2
M#Q^``````$PIZT^-9#0!2,'[`XE=`.NV#Q^``````$4QY.NJ#Q\`059!54%4
M55-(@>R@````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G]=3%(BX0D
MF````&1(*P0E*`````^%,0$``$B!Q*````!;74%<05U!7L-F+@\?A```````
M_Q7*F0``28G$2(7`=,%)B>5,B>?_%>::``!(A<`/A+4```"`>!,N2(U8$W4+
M@'L!`'3>#Q]$``"`>!,N#X2N````2(GO_Q6MF0``2(G?28G&_Q6AF0``08U\
M!@)(8___%3.:``!)B=E)B>B^`0```$F)QDB)QS'`2,?"_____TB-#>XZ``#_
M%=R:``!,B?=,B>[_%7B9``!,B?>#^/]T$(M$)!@E`/```#T`0```=&#_%=J8
M``!,B??_%<&8``!,B>?_%3B:``!(A<`/A5+___\/'X``````3(GG_Q5?F0``
M2(GO_Q4&F0``Z>#^__^0@'L!+@^%2/___X![`@`/A`W____I.?___P\?@```
M``#HB_[__^N?_Q7CF```#Q\`54B)_4B![*````!D2(L$)2@```!(B80DF```
M`#'`2(GF_Q6!F```A<!U-8M4)!B!X@#P``"!^@!```!T"('Z`*```'4=O@(`
M``!(B>__%9V9``"%P`^4P`^VP.L%#Q\`,<!(BXPDF````&1(*PPE*````'4)
M2('$H````%W#_Q5<F```9F8N#Q^$``````"054B)_?\5/I@``$B-5`7_2#G5
M<A7ID0````\?@`````!(@^H!2#G5="6`.B]T\D@YU7-W2(/J`4@YU702#Q]`
M`(`Z+W0H2(/J`4@YU77R@'T`+W1D2(T]<3D``%W_)3Z9``!F#Q]$``"`.B]U
M"4B#Z@%(.=5R\D@IZC'`2(U*`DB!^0`0``!W($B#P@&Y`!```$B)[DB-/:69
M``#_%7^8``!(C068F0``7<-(.=5UONN=#Q^``````$B-/0LY``!=_R7:F```
M9BX/'X0``````$%7NO\/``!!5D%5051)B?152(G]2(T]XS@``$B![!`0``!D
M2(L$)2@```!(B80D"!```#'`28GE3(GN_Q7OE@``A<!^>XU0_T2+/<&8``!,
M8_)"@#PT`'5?A=)T:DR)\KXO````3(GO_Q5BEP``2(7`=%1$B?__%927``!,
MB?%,B>I(B>Y(B<?_%1*8``!(BX0D"!```&1(*P0E*````'5`2('$$!```%U!
M7$%=05Y!7\-F#Q]$``!,8_#KH`\?`$2+/4F8``!$B?__%4"7``!,B>)(B>Y(
MB<?_%<F6``#KK?\5F98``&8/'X0``````$%7059!54%454B)]5-(B?M(@^P8
M9$B+!"4H````2(E$)`@QP#'`@#X]#Y3`2`'%2(GO_Q50E@``2(UT)`1(B=])
MB<0QP.@6^___2(7`#X0-`0``28G%2(G'_Q4IE@``23G$#X;8````3&-T)`1)
MP>8##[8#A,`/A*P!```\/0^$I`$``$B)V&8/'X0```````^V4`%(@\`!A-)T
M!8#Z/77O2"G82)A,`S63EP``2HU\(`+_%7"6``!)B09(A<!T64B+!7F7``!(
M8U0D!$B-2P%(BQ30#[8#B`*$P'0@/#UU"^L:#Q]$``"$P'01#[8!2(/"`4B#
MP0&(`CP]=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)`AD2"L$
M)2@````/A0\!``!(@\086UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(
M5`4`2(/``832=>[KO0\?0`!,BSW9E@``28,_``^$O@```$R)^$4Q[68/'X0`
M`````$B#P`A$B>I!@\4!2(,X`'7OC7(#2&/V2,'F`XL%WZ8``(7`=5O'!=&F
M```!````2(GW_Q5PE0``2(7`#X18____36/U3(G^2(G'2<'F`TR)\O\5L94`
M`$B)!6*6``!(B<%!C44!2)A(QP3!`````$2);"0$Z7C^__\/'X``````3(G_
M_Q5OE0``2(D%,)8``$B)P4B%P`^$_?[__TUC]4G!Y@/KO`\?`#'`Z7?^__^^
M$````$4Q[>E?_____Q5.E```9F8N#Q^$```````/'P!(@^P(BSW&E0``_Q7`
ME```BSVZE0``_Q6TE```2(L5W9,``$B-#>9S``!(C36<-0``2(G'_Q6VE```
MBSV0E0``_Q6*E```3(T%#C<``$4QR4B-%0D2``!(B<=,B<%(C36%-0``2(/$
M"/\ELI0``&:02(/L"(L]5I4``/\54)0``$B+%7F3``!(@\0(2(T-?G,``$B)
MQTB--3$U``#_)4Z4``!F9BX/'X0```````\?`$%455-(@>P@(```9$B+!"4H
M````2(F$)!@@```QP$B)Y4R-I"00$```_Q49DP``3(T-XS0``+H!$```2(GO
M08G`2(T-!C4``+X!````,<#_%:.4``"Z`!```$R)YDB)[_\5VI(``$4QP(7`
M>#"->`%(B<-(8___%:R3``!)B<!(A<!T&4ACVTR)YDB)QTB)VO\5>I,``,8$
M&`!)B<!(BX0D&"```&1(*P0E*````'4/2('$("```$R)P%M=05S#_Q7+D@``
M9F8N#Q^$``````#I*____V9F+@\?A```````05=!5D%528GU05152(G]2(T]
M9#0``%-(@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z$7W__^^+P``
M`$B)[TB)P_\5?)(``$B%P'0_,<!(B>Y(C3TF-```Z+[[__](B>A(BYPDJ!``
M`&1(*QPE*`````^%@P$``$B!Q+@0``!;74%<05U!7D%?PV:02(GO_Q4/D@``
M2(TU\#,``$R)[T&)Q/\5'),``$F)QDB%P'2=08`^`$R-+6LS```/A-H````/
M'P!(A=MT%$R)]DB)W_\5/Y(``(7`#X29````3(GW_Q6^D0``C5#_B<%(8\),
M`?"`."]U&68/'T0``(G1@^H!Q@``2&/"3`'P@#@O=.U"C40A`3W_#P``#X\N
M____N@`0``!-B?"^`0```#'`3(V\)*````!(@^P(2(T-030``%5,C0W?,@``
M3(G__Q7"D@``3(G_2(UT)"#_%5R1``!:687`=1"+1"0H)0#P```]`(```'16
M2(TU#S,``#'__Q4_D@``28G&2(7`#X2\_O__08`^``^%*?___TB%VW0%@#LN
M=!=-B>ZY`0```.E=____9BX/'X0``````(![`0!TM.OA#Q^$``````"^`0``
M`$R)__\5XI$``(7`=9A,B?Y(C3V7,@``Z"_Z__],B?__%0:2``#I9O[___\5
MJY```&9F+@\?A```````#[8'28GXA,!T%V8/'T0``$B#QP$\+P^V!TP/1,>$
MP'7O3(G`PV9F+@\?A```````2(7_=`N`/P!T!ND1^/__D$B-/=,Q``#_):.1
M```/'P!54TB-'2DR``!(@^Q(9@]O!1MP``!D2(L$)2@```!(B40D.#'`,<!(
MC6PD#`\11"009@]O!0=P``!FB40D,`\11"0@#Q]$```QP$B)[DB)W^C+]/__
M2(7`=#Y(8U0D#$B+!9J1``!(C0302(M0"$B)$$B%TG329BX/'X0``````$B+
M4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'9PQ``"0,<!(B>Y(B=_H<_3__TB%
MP'0V2&-4)`Q(BP5"D0``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```2(T=5#$``)`QP$B)[DB)W^@C]/__2(7`=#9(8U0D#$B+
M!?*0``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$
M``!(C1T-,0``D#'`2(GN2(G?Z-/S__](A<!T-DAC5"0,2(L%HI```$B-!-!(
MBU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'<0P``"0
M,<!(B>Y(B=_H@_/__TB%P'0V2&-4)`Q(BP52D```2(T$T$B+4`A(B1!(A=)T
MTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=A#```)`QP$B)[DB)W^@S
M\___2(7`=#9(8U0D#$B+!0*0``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!(C1WK+P``D#'`2(GN2(G?Z./R__](A<!T-DAC
M5"0,2(L%LH\``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#K
MOF8/'T0``$B-'?`O``"0,<!(B>Y(B=_HD_+__TB%P'0V2&-4)`Q(BP5BCP``
M2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=
MJB\``)`QP$B)[DB)W^A#\O__2(7`=#9(8U0D#$B+!1*/``!(C0302(M0"$B)
M$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1UD+P``D#'`2(GN
M2(G?Z//Q__](A<!T-DAC5"0,2(L%PHX``$B-!-!(BU`(2(D02(72=-)FD$B+
M4!!(@\`(2(D02(72=?#KOF8/'T0``$B-';0N``"0,<!(B>Y(B=_HH_'__TB%
MP'0V2&-4)`Q(BP5RC@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```2(GN2(T]RRX``.A9\?__2(G&2(7`=`Y(C3VC+@``,<#H
MX_7__TB)[DB-/;<N```QP.@R\?__2(G&2(7`=`Y(C3VS+@``,<#HO/7__TB)
M[DB-/:TN```QP.@+\?__2(G&2(7`=#I(C3WV+0``,<#HE?7__S'`2(TULRX`
M`$B-/1@N``#H@/7__TB+1"0X9$@K!"4H````=5%(@\1(6UW#2(GN2(T]:BX`
M`#'`Z+CP__](B<9(A<!T$$B-/?@M```QP.A"]?__ZZM(N%!!4E]#3$5!2#E$
M)"%UFF:!?"0I3CUUD4B-="0KZ\__%:F+``!F#Q^$``````!(@^P89$B+!"4H
M````2(E$)`B+!0B-``"#^/]T&TB+?"0(9$@K/"4H````=4)(@\08PV8/'T0`
M`$B-="0$2(T]>RT``#'`Z"7P__](B<(QP$B%TG02#[82@/HP#Y7!,<"$T@^5
MP"'(B06SC```ZZ[_%2N+``!F9BX/'X0``````$B#[`C_%1Z+``")Q_\5[HH`
M`$B%P'0#2(L`2(/$",.005152(G]2(T]C"T``%-(@^P09$B+!"4H````2(E$
M)`@QP$B-="0$Z*3O__](A<!T"(`X`$B)PW4W2(M$)`AD2"L$)2@````/A;T`
M``!(B>Y(@\002(T]/BT``#'`6UU!7.D*]/__9BX/'X0``````$B)[DB)Q_\5
MY(L``$B%P'0?2(M$)`AD2"L$)2@```!U>4B#Q!!;74%<PV8/'T0``$B)[_\5
M3XH``$B)WTF)Q/\50XH``$F-?`0"_Q78B@``2(/L"$F)Z+X!````4TC'PO__
M__](B<=)B<1,C0W_*P``2(T-[BP``#'`_Q5XBP``6%I(BT0D"&1(*P0E*```
M`'4(3(GFZ4;_____%?")``!!5T%6055)B?U(C3VJ*P``05154TB![(B!``!D
M2(L$)2@```!(B80D>($``$B-!7(L``!,C60D'$C'1"0P`````$C'A"2(````
M`````$R)YDC'1"10`````$B)1"0@2(T%!2L``$B)1"0H2(T%V"L``$B)1"1H
M2(T%+2P``$B)1"1P2(T%W2L``$B)1"1X2(T%'2P``$B)A"2`````2(T%$BP`
M`$B)1"1(,<#H$.[__TB%P'0,@#@`2(G%#X6O!```_Q4QB0``B<?_%0&)``!(
MA<`/A/@#``!(BRA(A>T/A.P#``!(B>__%?N(``!(C7P``?\5D(D``$0/MD4`
M2(G#183`=#=)B=],C36P*P``D$B#Q0%,B?],B?&^`0```$C'PO____\QP$F#
MQP+_%2:*``!$#[9%`$6$P'743(UT)&!(C3T(*P``ZQ=F#Q]$``!)BWX(28/&
M"$B%_P^$-P$``$R)YC'`Z%7M__](B<5(A<!TW8`X`'382(G'Z)#O__^%P'3,
M2(GO_Q6SB0``28G'2(7`#X3_````#Q^``````$R)__\5/X@``$B)WTB)Q?\5
M,X@``$2-M`4$!```36/V3(GW_Q6_B```4TV)^$R-#9@I``!(B<5(C07O*@``
MO@$```!(Q\+_____4$B-#=(J``!(B>\QP/\56XD``$B)[[[``0``_Q6-AP``
M7T%8@_C_=1/_%5^'``!$BPA!@_D1#X4@`P``2(VT))````!(B>__%8&'``")
MPX7`#X2_````28M-`$B+/72)``!)B>@QP$B-%2`K``"^`0```$4Q]O\5RH@`
M`$B+A"1X@0``9$@K!"4H````#X5^!0``2('$B($``$R)\%M=05Q!74%>05_#
M9@\?1```2(ML)"!%,?;K$V8/'T0``$ECQDB+;,0@2(7M=#N`?0``=#5(B>]!
M@\8!Z$GN__^%P'3=2(GO_Q5LB```28G'2(7`#X7`_O__26/&2(MLQ"!(A>UU
MR`\?`$4Q_^FH_O__#Q^$``````"+A"2H````)0#P```]`$````^%*O___T2+
MO"2L````_Q73A@``03G'#X43____BX0DJ````"7_`0``/<`!```/A?S^__],
MB??_%3J'``!(C3T_*0``3(GF28G&,<#H7NO__TB)QTB%P`^$0@(``/\5S(<`
M`$F+?0!(B<;HP//__TF)QTB%P`^$)`(``$R)__\54X8``(/X`WX^2&/0N04`
M``!(C3TI*0``28UT%_SSI@^7PH#:`(32=1Z#^`0/A(D#``"#Z`5(F$&`/`<O
M#X1Y`P``#Q]$``"+!9*'``"#^/\/A"D#``"%P`^$U`$``$B--9$H``!(C3T2
M*```,<#H7.___TR-)0`I``!,C2U:)P``_Q60A0``051)B>B^`0```%!(Q\+_
M____3(GW,<!,C0TV)P``2(T-KB@``/\5%8<``%A:ZTUF#Q^$``````#_%2*%
M``"#.!%U3/\51X4``(/#`4B#[`A-B>E!5$F)Z$B-#8(H``!,B?=32,?"____
M_[X!````4#'`_Q7(A@``2(/$(+[``0``3(GW_Q7VA```@_C_=*E(B>__%<"$
M``!,B?9(C3T`)P``,<#HG^[__TR)]^@G^O__Z9C]__]FD#';2(T]P"<``.L2
M#Q]$``!(8\-(BWS$0$B%_W0Y3(GF,<"#PP'HQNG__TB%P'3A@#@`=-Q(B<?_
M%3.&``!(B<5(A<`/A<O[__](8\-(BWS$0$B%_W7'OPT```!(C2UL)P``_Q50
MA0``0;A3````2(G#Z;_[__])BTT`2(L];X8``$F)Z#'`2(T5VR<``+X!````
M13'V_Q7%A0``Z?;\__](B<?H>/G__TB+A"1X@0``9$@K!"4H````#X5L`@``
M2('$B($``$B)[UM=05Q!74%>05__)9>%```/'X``````38M]`.G3_?__QP6M
MA0```````#'V3(G_,<#_%1"%``!!B<2%P`^$%/[__TB-G"1P`0``N@(```!(
MQ\;N____B<?_%3&%``"Z!@```$B)WD2)Y_\50(0``("\)'`!````=0Z`O"1Q
M`0``0P^$;P$``#'2,?9$B>?_%?N$```QP&?H^QL``$F)Q>L49@\?1```B<)(
MB=Y,B>]GZ$(<``"Z`(```$B)WD2)Y_\5Z8,``(7`?]U,C;PD(`$``$2)YTR-
M)4HF``#_%:V#``!,B>Y,B?],C:PD:`$``&?HL1T``$B-A"1``0``2(E$)`A(
MB<.02(G?2(/#`D4/M@=,B>%(Q\+_____O@$````QP$F#QP'_%9*$``!).=UU
MU4B-!3DF``#&A"1H`0```%#_="002(T-]B4``$F)Z$R)]S'`O@$```!,C0UR
M)```2,?"______\5480``%E>Z9G]__]FD#'`3(GF2(T]\R0``.B?Y___2(7`
M#X2/_O__#[8`A,`/A(3^__\\,`^$?/[__\<%*80```$```#IH_S__TV+;0A-
MA>T/A'_\__],B>__%8:"``!(@_@##X9L_/__28UT!?RY!0```$B-/5HE``#S
MI@^7P!P`A,!-#T3]Z4G\__^`O"1R`0``00^%@_[__X"\)',!``!##X5U_O__
M@+PD=`$``$@/A6?^__^`O"1U`0``10^%6?[__[H"````2,?&QO___T2)Y_\5
M3(,``+HI````2(G>1(GG_Q5;@@``2(T%%R4``%!3Z>3^____%>^!``!F9BX/
M'X0```````\?0`!!54%454B#[!"+/6&#``!D2(L$)2@```!(B40D"#'`_Q5+
M@@``BSU%@P``2(G%_Q4\@@``#[:5N````$B-;"0$2(T]G",``$B)[HB0N0``
M`#'`Z%GF__](A<!T"8`X,0^$PP$``#'`Z"3Q__^+/?Z"``#_%?B!``"Y`P``
M`+H!````2(TU<20``$B)Q_\5OH$``$F)Q$B%P'0Z2(M`$(L]S((``$R+*/\5
MPX$``$B-%4@D``!(B<=,B>[_%4B!``!)BT0D$$R+($'V1"0.0`^%G`$``(L]
MEH(``/\5D($``+D#````N@$```!(C340)```2(G'_Q56@0``28G$2(7`=$!(
MB>Y(C3VG(@``,<#HG>7__TF)Q4B%P`^$(0$``$F+1"00BSU&@@``3(L@_Q4]
M@0``3(GJ2(G'3(GF_Q7&@```BSTH@@``_Q4B@0``N@$```!(C36I(P``2(G'
M_Q4=@0``BST'@@``28G$_Q7^@```3(GF2(T5G",``$B)Q_\5@X```(L]Y8$`
M`/\5WX```$B)[DB-/0\B``#&@+D`````,<#H!^7__TB)!2B2``!)B<1(A<!T
M0+[``0``3(GG_Q7"?P``C5`!@_H!=@F#^!$/A;8```!(BT0D"&1(*P0E*```
M``^%P````$B#Q!!=05Q!7<,/'P!(BSWAD0``Z.SU__](B07-D0``28G$2(7`
M=:5(C3VF(P``,<#_%6:```!F#Q]$``"`>`$`#X0Z_O__Z2[^__]F#Q^$````
M``!(BP69D0``BSTC@0``3(LH28M$)!!,BR#_%1*```!,B>Y,B>?H]^?__^G4
M_O__9I"+/?J```#_%?1_``!,B>9(B<?_%2"```#I1_[__XG!2(L%2I$``$R)
MXDB-/4@C``!(BS`QP/\5W7\``/\5+W\``&9F+@\?A```````#Q]``$%454B)
M_5-(@^P09$B+!"4H````2(E$)`@QP$B%_P^$O````(`_``^$LP```.B>YO__
M#[802(G#A-)T%@\?0`!(@\`!@/HO#[802`]$V(32=>Z+!4B```!(A>U!#Y7$
M@_C_#X20````A<`/E<!!(<1%A.1U(TB+1"0(9$@K!"4H````#X6P````2(/$
M$%M=05S#9@\?1```@'T``'37N00```!(C3U3(0``2(G>\Z8/E\`<`(3`=;U(
MBT0D"&1(*P0E*````'5Q2(/$$$B)[UM=05SIZ./__P\?A```````2(T]LQ\`
M`/\5@W\``.E`____9@\?1```,<!(C70D!$B-/3D@``#HY>+__TB%P'0+#[8`
MA,!T!#PP=0_'!7M_````````Z4O____'!6Q_```!````Z3?_____%>%]``"0
M05=,C4\X059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-
ME"2`````28G09BX/'X0``````$&+`4F+,4F#P!!)@\$(#\B)P$B)\4F)0/!(
MB?!(P>D@2,'H*$C![C@E`/\``$@)\$B)SDC!X0A(P>88@>$``/\`B?9("?!(
M"<A)B4#X33G0=:Y(C;(``@``#Q^``````$B+0FA(,T)`2(/""$@S0@A(,T+X
M2(T,`$C!Z!]("<B#X/](B4)X2#GR==5,BP],BU\02(MW($B+7QA,B<A,B<I(
MBV\(2,'J&TC!X`5("=`#!"2-E#"9>8):3(G82(MT)`A(,=A((>A(C;0SF7F"
M6D@QV$2-%`)(B>I(B>A(P>@"2,'B'DV)T$@)PDR)V$G!Z!N)T4@QR$PAR$PQ
MV$@!\$R)UDC!Y@5,"<9$C30P3(G.3(G(2,'F'DC!Z`)-B?!("?!(BW0D$$G!
MZ!M(,<)!B<5,(=))C;0SF7F"6D@QRD@!\DR)]DC!Y@5,"<9$C00R3(G62<'J
M`DB+5"082,'F'DP)UDB-E!&9>8):3(G!2#'P08GT3"'P3#'H2,'I&T@!T$R)
MPDC!X@5("<I,B?%)P>X"2,'A'D2-%!!(B?!(BU0D($P)\4R)UD@QR$F-E!69
M>8):2,'N&T&)SDPAP$PQX$@!T$R)TDC!X@5("?)$C2P03(G"2<'H`DB+1"0H
M2,'B'DR)[DP)PDF-A`29>8):2,'N&T@QT4&)T$PAT4PQ\4@!P4R)Z$C!X`5(
M"?!$C20!3(G02<'J`DB+3"0P2,'@'DR)YDP)T$F-C`Z9>8):2#'"08G"3"'J
M3#'"2`'*3(GA2,'A!4C![AM("?%,B>Y)P>T"2,'F'D2--`I(BU0D.$P)[DR)
M\4@Q\$F-E!"9>8):2,'I&T&)]4PAX$PQT$@!T$R)\DC!X@5("<I,B>%)P>P"
M2,'A'D2-!!!(B?!(BU0D0$P)X4R)QD@QR$F-E!*9>8):2,'N&T&)S$PA\$PQ
MZ$@!T$R)PDC!X@5("?)$C1003(GR2<'N`DB+1"1(2,'B'DR)UDP)\DF-A`69
M>8):2,'N&T@QT4&)UDPAP4PQX4@!P4R)T$C!X`5("?!$C2P!3(G`2<'H`DB+
M3"102,'@'DR)[DP)P$F-C`R9>8):2,'N&T@QPD&)P$PATDPQ\D@!RDR)Z4C!
MX05("?%,B=9)P>H"2,'F'D2-)`I(BU0D6$P)UDR)X4@Q\$F-E!:9>8):2,'I
M&T&)\DPAZ$PQP$@!T$R)XDC!X@5("<I,B>E)P>T"2,'A'D2--!!(B?!(BU0D
M8$P)Z4R)]D@QR$F-E!"9>8):2,'N&T&)S4PAX$PQT$@!T$R)\DC!X@5("?)$
MC0003(GB2(M$)&A(P>(>2<'L`DR)QDP)XDF-A`*9>8):2,'N&T@QT4&)U$PA
M\4PQZ4@!P4R)P$C!X`5("?!$C10!3(GP2<'N`DB+3"1P2,'@'DR)UDP)\$F-
MC`V9>8):2,'N&T@QPD&)QDPAPDPQXD@!RDR)T4C!X05("?%,B<9)P>@"2,'F
M'D2-+`I(BU0D>$P)QDR)Z4@Q\$F-E!29>8):2,'I&T&)\$PAT$PQ\$@!T$R)
MZDC!X@5("<I,B=%)P>H"2,'A'D2-)!!(B?!(BY0D@````$P)T4R)YD@QR$F-
ME!:9>8):2,'N&T&)RDPAZ$PQP$@!T$R)XDC!X@5("?)$C3003(GJ2<'M`DB+
MA"2(````2,'B'DR)]DP)ZDF-A`"9>8):2,'N&T@QT4&)U4PAX4PQT4@!P4R)
M\$C!X`5("?!$C00!3(G@2<'L`DB+C"20````2,'@'DP)X$F-C`J9>8):38G"
M2#'"2<'J&XG&3"'R3#'J2`'*3(G!2,'A!4P)T4V)\DG![@))P>(>B<E-"?)(
M`<I(BXPDF````$PQT$&)U$PAP$F-C`V9>8):38GE2#'P2<'M&T@!R$R)X4C!
MX05,">F)R4@!R$R)P4G!Z`)(P>$>08G%3`G!38G018G23`.4)*@```!),<A$
M,<),BX0DH````$Z-A`:AZ]EN3(GN20'03(GJ2,'N&TC!X@5("?*)TDD!T$R)
MXDG![`)(P>(>1(G&3`GB28G,B<E(`XPDL````$DQU$0QX$F)]$V-E`*AZ]EN
M2(GP2<'L&TC!X`5,">")P$D!PDR)Z$G![0)(P>`>18G43`GH28G5B=)),<5%
M,>A-B>5(`Y0DN````$Z-A`&AZ]EN3(GA2<'M&TC!X05,">F)R4P!P4F)\$C!
M[@))P>`>08G-20GP2(G&B<!(`X0DP````$PQQD$Q\DJ-M!*AZ]EN3(GJ38GJ
M2<'J&TC!X@5,"=*)TD@!\DR)YDG![`)(P>8>08G23`GF38G$18G`3`.$),@`
M``!),?1$,>%-B=1(C8P(H>O9;DR)T$G![!M(P>`%3`G@B<!(`<A,B>E)P>T"
M2,'A'D&)Q$P)Z4F)]8GV23'-1#'J38GE38V$$*'KV6Y,B>)(P>(%2<'M&T@#
MM"30````3`GJB=))`=!,B=))P>H"2,'B'D6)Q4P)TDF)RHG)2`.,)-@```!)
M,=)$,=!-B>I(C;0&H>O9;DR)Z$G!ZAM(P>`%3`G0B<!(`<9,B>!)P>P"2,'@
M'D&)\DP)X$F)U(G22`.4).````!),<1%,>!-B=1.C80!H>O9;DR)T4G![!M(
MP>$%3`GAB<E,`<%-B>A)P>T"2<'@'D&)S$T)Z$F)Q8G`33'%1#'N38GE2(VT
M,J'KV6Y,B>))P>T;2,'B!4P)ZHG22`'R3(G62<'J`D@#A"3H````2,'F'D&)
MU4P)UDV)PD6)P$P#A"3P````23'R1#'138GJ2(V,"*'KV6Y,B>A)P>H;2,'@
M!4P)T(G`2`'(3(GA2<'L`DC!X1Y!B<),">%)B?2)]D@#M"3X````23',1#'B
M38G438V$$*'KV6Y,B=))P>P;2,'B!4P)XHG220'03(GJ2<'M`DC!XAY%B<1,
M">I)B<V)R4DQU40QZ$V)Y4B-M`:AZ]EN3(G@2<'M&TC!X`5,">B)P$@!QDR)
MT$C!X!Y)P>H"08GU2`.,)``!``!,"=!)B=*)TD@#E"0(`0``23'"13'038GJ
M3HV$`:'KV6Y,B>E)P>H;2,'A!4P)T8G)3`'!38G@2<'L`DG!X!Y!B<I-">!)
MB<2)P$@#A"00`0``33'$1#'F38G42(VT,J'KV6Y,B=))P>P;2,'B!4P)XHG2
M2`'R3(GN2<'M`DC!YAY!B=1,">Y-B<5%B<!),?5$,>E-B>5(C8P(H>O9;DR)
MX$G![1M(P>`%3`GHB<!(`<A,B=%)P>H"2,'A'D&)Q4P)T4F)\DP#A"08`0``
MB?9),<I(`[0D(`$``$0QTDV-M!"AZ]EN3(GJ38GH2<'H&TC!X@5,"<))B<B)
MR4@#C"0H`0``B=))`=9,B>))P>P"2,'B'D6)\DP)XDDQT$0QP$R-I`:AZ]EN
M3(G03(G62,'N&TC!X`5("?!(B=:)TD@#E"0P`0``B<!)`<1,B>A)P>T"2,'@
M'D6)X$P)Z$@QQD$Q]DR)QDZ-K#&AZ]EN3(G!2,'N&TC!X05("?&)R4D!S4R)
MT4G!Z@)(P>$>1(GN3`G128G"B<!),<I%,=1(`X0D.`$``$Z-E"*AZ]EN2(GR
M28GT2<'L&TC!X@5,">)-B<1)P>@"2<'D'D$!TDT)Q$F)R(G)33'@1(GB13'%
M3HV$**'KV6Y,B=!-B=5)P>T;2,'@!4P)Z$R+K"1``0``18TT`$F)\$C![@),
MB>!)P>`>20GP1(G&3`G`3"'022'T20G$N-R\&X])`<5,`>E-B?5,`>%-B?1)
MP>T;2<'D!4T)[$$!S$R)T4G!Z@)(P>$>3`G120G(28G-08G*32'P22'U30GH
M3(NL)$@!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD6-+!!,B?))P>X"
M2,'B'DP)\DF)SD&)T$D)UDTAYDPAP4P)\4R+M"10`0``20'&3`'V38GN2`'Q
M3(GN2<'N&TC!Y@5,"?9$C30Q3(GF2<'L`DC!YAY,">9("?))B?2)\4TAQ$PA
MZDP)XDR+I"18`0``20'$30'B38GT3`'238GR2<'B!4G![!M-">)&C20238GJ
M2<'M`DG!XAY-">I)B?5$B=)-"=5-(?5((=9,">Y,BZPD8`$``$D!Q4T!Z$V)
MY4P!QDV)X$G![1M)P>`%30GH1HTL!DV)\$G![@))P>`>30GP30G"38G&1(G&
M22'632'B30GR3(NT)&@!``!)`<9,`?%-B>Y)`<I,B>E)P>X;2,'A!4P)\46-
M-`I,B>%)P>P"2,'A'DP)X4V)Q$D)S$&)RDTA[$TAT$T)X$R+I"1P`0``20'$
M3`'B38GT20'03(GR2<'L&TC!X@5,">)%C2003(GJ2<'M`DC!XAY,">I("=%)
MB=5!B=!-(=5,(?%,">E,BZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%
M3`GN1(TL,4R)]DG![@)(P>8>3`GV28G6B?%)"?9-(>9((<I,"?),B[0D@`$`
M`$D!QDT!\DV)[DP!TDV)ZDG![AM)P>(%30GR1HTT$DV)XDG![`))P>(>30GB
M3`G638G41(G222',3"'N3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;
M2<'@!4T)X$:-)`9-B>A)P>T"2<'@'DT)Z$V)U42)QDT)Q4TA]4DA\DT)ZDR+
MK"20`0``20'%3`'I38GE20'*3(GA2<'M&TC!X05,">E%C2P*3(GQ2<'N`DC!
MX1Y,"?%)"<A)B<Y!B<I)(?9-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)
MZDG![AM(P>(%3`GR18TT$$R)XDG![`)(P>(>3`GB28G,08G020G432'L3"'!
M3`GA3(ND)*`!``!)`<1,`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)#%,B>Y)
MP>T"2,'F'DP)[D@)\DF)]8GQ32'%3"'R3`GJ3(NL)*@!``!)`<5-`>I-B>5,
M`=)-B>))P>T;2<'B!4T)ZD:-+!)-B?))P>X"2<'B'DT)\DF)]D2)TDT)UDTA
MYD@AUDP)]DR+M"2P`0``20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!&C30&
M38G@2<'L`DG!X!Y-">!-"<)-B<1$B<9)(=1-(>I-">),BZ0DN`$``$D!Q$P!
MX4V)]$D!RDR)\4G![!M(P>$%3`GA18TD"DR)Z4C!X1Y)P>T"3`GI38G%08G*
M20G-32'U32'030GH3(NL),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)
MZD6-+!!,B?))P>X"2,'B'DP)\D@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(`0``
M20'`3`'&38GH2`'Q3(GN2<'H&TC!Y@5,"<9$C00Q3(GF2<'L`DB)T4C!YAY,
M">9!B?1("?%,(>E,(>)("<I(BXPDT`$``$@!P4@#A"38`0``20'*3(G!20''
M3`'238G"2,'A!4G!ZAM,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI3(G02`G.
M28G-2,'@!4&)SDTAY4PAQDP)[DV)U4G![1M,`?Y,">B)P$@!QDR)P$G!Z`)(
MP>`>08GU20G`N-;!8LI,,<$QRDB+C"3@`0``2`'!3`'A38GL2`'13(GJ2<'L
M&TC!X@5,">*)TD@!T4R)TDG!Z@)(P>(>08G,20G23(G"18G`3#'2,=9(BY0D
MZ`$``$@!PDD!UDR)XDP!]DV)YDC!X@5)P>X;3`GRB=),C3063(GJ2<'M`DR)
MUDC!XAY%B?=%B=))"=5(BY0D\`$``$PQ[D@!PC'Q3(G^3`'"2,'N&T@!T4R)
M^DC!X@5("?)(B[0D^`$``(G22`'13(GB2`'&2<'L`DC!XAY,`=9-B>I!B<A,
M">)-B<1%B>U),=)%,=9.C10V3(G&2,'F!4G![!M,">:)]DD!\DR)_DG![P)(
MP>8>18G420GW2(NT)``"``!(`<9,`>Y)B=6)TDTQ_40QZ4R-+`Y,B>%,B>9(
MP>X;2,'A!4@)\4R)QDG!Z`*)R4C!YAY)`<U(BXPD"`(``$P)QDV)^$DQ\$6)
M[D6)_T@!P44QPD@!RDR)\4Z-!!),B?)(P>D;2,'B!4@)RDB)\8GVB=))`=!,
MB>))P>P"2,'B'D6)PDD)U$B+E"00`@``3#'A2`'"03'-3(G13`'Z20'53(G2
M2,'I&TC!X@5("<I,B?%)P>X"B=)(P>$>20'52(N4)!@"``!,"?%%B>](`<)(
M`?),B>9%B>1(,<Y!,?!,B?Y)`=!,B?I(P>X;2,'B!4@)\HG220'03(G22<'J
M`DC!XAY%B<9)"=)(BY0D(`(``$R)]DC![AM(`<),`>))B<R)R4TQU$4QY4Z-
M)"I,B?)(P>(%2`GR2(NT)"@"``")TDD!U$R)^D@!QDG![P)(P>(>18GE3`GZ
M2`'Q3(G618G22#'603'P3(GN20'(3(GI2,'N&TC!X05("?&)R4D!R$R)\4G!
M[@)(P>$>18G'20G.2(N,)#`"``!,B?Y(P>X;2`'!3`'128G2B=)-,?)%,=1.
MC10A3(GY2,'A!4@)\4R)[DG![0*)R4C!YAY)`<I(BXPD.`(``$P)[D6)U$@!
MP4@!RDR)\46)]D@Q\4$QR$R)X4D!T$R)XDC!Z1M(P>(%2`G*2(GQB?:)TDD!
MT$R)^DC!XAY)P>\"18G%20G72(N4)$`"``!,,?E(`<)!,<I,B>E,`?)(P>D;
M20'23(GJ2,'B!4@)RDR)X4G![`*)TDC!X1Y)`=)(BY0D2`(``$P)X46)_$6)
MUD@!PD@!\DR)_D@QSD$Q\$J--`),B?)-B?!)P>@;2,'B!4P)PHG22`'63(GJ
M2<'M`DC!XAY!B?!)"=5(BY0D4`(``$@!PDP!XDF)S(G)33'L13'B3HTD$DR)
MPDV)PDG!ZAM(P>(%3`G2B=))`=1,B?))P>X"2,'B'D6)XDP)\DR+M"18`@``
M20'&3`'Q38GN18GM23'61#'V38G62`'.3(G12<'N&TC!X05,"?&)R4@!SDR)
MP4G!Z`)(P>$>08GV20G(2(N,)&`"``!(`<%)`<U(B=&)TDPQP4$QS$N-3"4`
M38GT38GU2<'M&TG!Y`5-">Q-B=5)P>H"2<'E'D6)Y$T)ZDR+K"1H`@``3`'A
M08G,20'%3`'J38G%18G`33'51#'N3(TL,DR)XDR)YDC!X@5(P>X;2`GRB=))
M`=5,B?))P>X"2,'B'D2)[DD)UDB+E"1P`@``2`'"2`.$)'@"``!,`<)-B=!-
M,?!$,<%)B?!(`<I(B?%)P>@;2,'A!4P)P46)T`'13(GB2<'L`DC!XAY)"=1*
MC10(2(G(20'03(GR2,'@!40!XTPQXDB)7QA!,=5+C10H28G(`>E)P>@;2(E/
M"$P)P`'02(D'2(GP2,'N`DC!X!Y("<9!`?-$`W<@3(E?$$R)=R!(BX0DB`(`
M`&1(*P0E*````'422('$F`(``%M=05Q!74%>05_#_Q7#9P``#Q\`2(/L"+^`
M````_Q5):```NHFKS>^Y_MRZF+[PX=+#2,<``2-%9TB)4`A(B4@02,=`&'94
M,A!(B7`@2,=`*`````!(QT`P`````,=`>`````!(@\0(PV9F+@\?A```````
M05=(8\)!5DF)QD%5051)B?Q52(UO.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(
MB4\H2(/2`$C!Z!U(`=!(B4<P2&-'>(7`#X7M````08/^/P^.,P$``$&#[D!%
MB?=!P>\&18UO`4G!Y09)`=T/'T0``/,/;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-
M$/,/;U/@#Q%5(/,/;UOP#Q%=,.CAZ/__3#GK=<Q!P><&12G^26/&2(/X"')<
M28M5`$F)5"0X28M4!?A(B50%^$B-50A(@^+X2"G522GM2`'%2(/E^$B#_0AR
M&$B#Y?@QP$F+3`4`2(D,`DB#P`A(.>AR[D6)="1X2(/$"%M=05Q!74%>05_#
M9I"H!'5\2(7`=.%!#[95`$&(5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``0;U`
M````2(U\!0!(B=Y!*<5%.>Y%#T[N36/]3(GZ_Q6$9@``08M$)'A$`>A!B40D
M>(/X0'613(GG12GN3`'[Z`3H___IRO[__P\?@`````!)B=WI&____T&+50!!
MB50D.$&+5`7\B50%_.E3____9@\?A```````059,C78X055!5%5(B?532(M&
M*$B)^T2+9BA$BVXP2,'H`X/@/T$/S$$/S8U(`4B8QD0&.(!(8\%,`?"#^3@/
MCBP!``"^0````"G.=`\QTHG1@\(!Q@0(`#GR<O-(B>_H;.?__V8/[\`/$44X
M2<=&,`````!!#Q%&$$$/$48@1(EM<$B)[T2)973H0N?__TB+10!(B>](P>@8
MB`-(BT4`2,'H$(A#`4B+10!(P>@(B$,"2(M%`(A#`TB+10A(P>@8B$,$2(M%
M"$C!Z!"(0P5(BT4(2,'H"(A#!DB+10B(0P=(BT402,'H&(A#"$B+11!(P>@0
MB$,)2(M%$$C!Z`B(0PI(BT40B$,+2(M%&$C!Z!B(0PQ(BT482,'H$(A##4B+
M11A(P>@(B$,.2(M%&(A##TB+12!(P>@8B$,02(M%($C!Z!"(0Q%(BT4@2,'H
M"(A#$DB+12"(0Q-;74%<05U!7O\ERF,``&8N#Q^$``````"Z.````#'_*<J#
M^@AR0HG12,<``````$C'1`CX`````$B-2`A(@^'X2"G(`<*#XOB#^@@/@M7^
M__^#XO@QP(G&@\`(2(D\,3G0<O/IOO[___;"!'4CA=(/A+'^___&``#VP@(/
MA*7^__\QR6:)3!#^Z9G^__\/'P#'``````#'1!#\`````.F#_O__#Q]$``#S
M#Q[Z05=,C3W38```059)B=9!54F)]4%408G\54B-+<1@``!33"G]2(/L".CO
MQ/__2,']`W0?,=L/'X``````3(GR3(GN1(GG0?\4WTB#PP%(.=UUZDB#Q`A;
M74%<05U!7D%?PV9F+@\?A```````\P\>^L-F+@\?A```````D/,/'OI(BPV=
M9```Z<#$___S#Q[Z2(/L"$B#Q`C#````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"X`+P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0
M051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R
M>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-3(`+64`+2T``````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B10
M05)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(
M+"`G/#IR87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*
M)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H
M=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E
M;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI
M;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@
M,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I
M*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N
M<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S
M96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U
M9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L
M92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM
M>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E
M='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)
M3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I
M;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ
M92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L
M;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F
M:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R
M96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@
M)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R
M96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O
M<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM
M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R
M(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E
M86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A8
M6"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*
M:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E
M('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1
M)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I
M.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\
M*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K
M:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD
M968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E
M("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L
M("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S
M("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC
M;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I
M(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?
M1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D[
M"B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*
M?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*
M?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR
M97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y
M;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E
M<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT
M;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(
M86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A
M73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L
M(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R
M.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM
M>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^
M:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92![
M"B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I
M92!Q<5M#86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P
M97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`!&P,[_````!X```"0@?__,`$``+"!__^\!0``T(/__Q@!``#0A/__6`$`
M`*"%__^D`0``((?__^@!``"PA___#`(``("(__\T`@``<(G__W@"``#`B___
MQ`(``#",___<`@``<(S___0"``!`C?__*`,``%"-__\\`P``8(___YP#``"0
MC___L`,``+"/___$`P``8)3___`#``#@E/__#`0```"5__\D!```$);__W0$
M```@GO__1`4``."@__]X!0``(*+__^@%``!`N/__.`8``*"X__]0!@``4+K_
M_YP&``!0O/__X`8``,"\__\H!P``T+S__T`'````````%``````````!>E(`
M`7@0`1L,!PB0`0``%````!P```"P@O__+P````!$!Q``````)````#0```!8
M@/__(``````.$$8.&$H/"W<(@``_&CLJ,R0B`````$@```!<````<(/__\T`
M````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FT*#CA$#C!!
M#BA"#B!"#AA"#A!"#@A("P!`````J````/2#__]]`0```$(.$(X"0@X8C0-"
M#B",!$$.*(8%00XP@P9'#M`!?@H.,$$.*$$.($(.&$(.$$(."$L+`"````#L
M````,(7__X0`````00X0A@)*#K`!`G$*#A!!#@A!"R0````0`0``G(7__\8`
M````00X0A@("6PH."$P+`D$*#@A!"U8."`!`````.`$``$2&___G`````$(.
M$(\"1PX8C@-"#B"-!$(.*(P%1`XPA@91#L`@`H8*#C!!#BA"#B!"#AA"#A!"
M#@A'"T@```!\`0``\(;__T("````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&
M!D0..(,'1PY0`QT!"@XX00XP00XH0@X@0@X80@X00@X(10L4````R`$``/2(
M__]N`````$0.$`)D#@@4````X`$``$R)__\R`````$0.$%<."``P````^`$`
M`'2)___%`````$(.$(P"00X8A@-!#B"#!$<.P$`"K`H.($0.&$$.$$(."$$+
M$````"P"```0BO__!0````````!<````0`(```R*__\%`@```$(.$(\"0@X8
MC@-"#B"-!$4.*(P%00XPA@9+#CB#!T<.\"$"90H..$$.,$$.*$(.($(.&$(.
M$$(."$,+`JX.^"%(#H`B7P[X(4$.\"$````0````H`(``+R+__\E````````
M`!````"T`@``V(O__QT`````````*````,@"``#DB___IP0```!!#A"&`D$.
M&(,#2PY@`T<$"@X800X000X(00L8````]`(``&B0__]U`````$0.(&T*#@A'
M"P``%````!`#``#,D/__'P````!$#A!:#@@`3````"@#``#4D/__$`$```!"
M#A",`D$.&(8#2PX@@P1$#C`"0@H.($H.&$$.$$(."$\+90H.($$.&$$.$$(.
M"$<+9`XX20Y`9`XX00XP``#,````>`,``)21__\!"````$(.$(\"0@X8C@-"
M#B"-!$P.*(P%00XPA@9!#CB#!T<.P(,"`Z\!#LB#`F$.T(,"80[(@P)"#L"#
M`@)V"@XX1`XP00XH0@X@0@X80@X00@X(1PL#@@$.R(,"20[0@P)A#LB#`D$.
MP(,"8P[(@P)%#M"#`DX.V(,"30[@@P),#L"#`@,"`0H..$0.,$$.*$(.($(.
M&$(.$$(."$T+`RL!#LB#`D0.T(,":0[(@P)!#L"#`@+L"@[(@P)!#M"#`D4+
M,````$@$``#4F/__L0(```!"#A"-`D(.&(P#00X@A@1$#C`#Y@$*#B!!#AA"
M#A!"#@A$"T````!\!```8)O__S\!````0@X0C`)!#AB&`T0.((,$1`XP`H(*
M#B!!#AA!#A!"#@A'"W0*#B!$#AA!#A!"#@A-"P``*````,`$``#L>___'@(`
M``!"#A",`D$.&(8#1`Y0`[`!"@X81`X00@X(00M,````[`0``#"<__\=%@``
M`$(.$(\"1@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#]Q4*#CA!#C!!
M#BA"#B!"#AA"#A!"#@A!"P```!0````\!0```++__U4`````1`X0`E`."$@`
M``!4!0``2++__Z<!````0@X0CP)%#AB.`T4.((T$0@XHC`5$#C"&!D4..(,'
M1PY``N4*#CA!#C!!#BA"#B!"#AA"#A!"#@A#"P!`````H`4``*RS___[`0``
M`$(.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#2@$*#BA!#B!"#AA"#A!"#@A0
M"P```````$0```#D!0``:+7__V4`````1@X0CP))#AB.`T4.((T$10XHC`5$
M#C"&!D@..(,'1PY`;@XX00XP00XH0@X@0@X80@X00@X(`!0````L!@``D+7_
M_P4``````````````!````!$!@``B+7__Q``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````4",`````````(P````````$`````````Y0(````````!`````````/`"
M`````````0```````````P````````\`````````E@0````````,````````
M```@````````#0````````!P6P```````!D`````````P+L````````;````
M``````@`````````&@````````#(NP```````!P`````````"`````````#U
M_O]O`````,`#````````!0````````"`#@````````8`````````:`4`````
M```*`````````+D$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````8`````````!0`````````
M!P`````````7`````````"`;````````!P````````"0%`````````@`````
M````D`8````````)`````````!@`````````&````````````````````/O_
M_V\``````0``"`````#^__]O```````4````````____;P`````"````````
M`/#__V\`````.A,```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#0NP``````````````````````````
M```V(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#@8@```````$=#
M0SH@*$=.52D@,3`N,BXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@`````````8`P```````!@#
M````````'`````````````````````$````````````````````3````!P``
M``(`````````.`,````````X`P```````$`````````````````````(````
M````````````````)@````<````"`````````'@#````````>`,````````D
M````````````````````!````````````````````#D````'`````@``````
M``"<`P```````)P#````````(`````````````````````0`````````````
M``````!'````]O__;P(`````````P`,```````#``P```````*@!````````
M!@`````````(````````````````````40````L````"`````````&@%````
M````:`4````````8"0````````<````!````"``````````8`````````%D`
M```#`````@````````"`#@```````(`.````````N00`````````````````
M``$```````````````````!A````____;P(`````````.A,````````Z$P``
M`````,(`````````!@`````````"``````````(`````````;@```/[__V\"
M```````````4`````````!0```````"0``````````<````"````"```````
M`````````````'T````$`````@````````"0%````````)`4````````D`8`
M```````&``````````@`````````&`````````"'````!````$(`````````
M(!L````````@&P```````!@`````````!@```!8````(`````````!@`````
M````D0````$````&```````````@`````````"`````````;````````````
M````````!````````````````````(P````!````!@`````````@(```````
M`"`@````````(````````````````````!``````````$`````````"7````
M`0````8`````````0"````````!`(````````#`[```````````````````0
M````````````````````G0````$````&`````````'!;````````<%L`````
M```-````````````````````!````````````````````*,````!`````@``
M````````8`````````!@````````D#X``````````````````!``````````
M``````````"K`````0````(`````````D)X```````"0G@```````/P`````
M```````````````$````````````````````N0````$````"`````````)"?
M````````D)\```````!8!@``````````````````"```````````````````
M`,,````.`````P````````#`NP```````,"K````````"```````````````
M``````@`````````"`````````#/````#P````,`````````R+L```````#(
MJP````````@````````````````````(``````````@`````````VP````8`
M```#`````````-"[````````T*L````````@`@````````<`````````"```
M```````0`````````.0````!`````P````````#PO0```````/"M````````
M$`(```````````````````@`````````"`````````#I`````0````,`````
M`````,``````````L````````"`````````````````````(````````````
M````````[P````@````#`````````"#`````````(+````````"`$```````
M````````````(````````````````````/0````!````,```````````````
M`````""P````````$@````````````````````$``````````0`````````!
M`````P`````````````````````````RL````````/T`````````````````
2```!````````````````````
